@@ -33,6 +33,7 @@ from shapely.ops import unary_union
 from . import settings
 from .projection import project_geometry
 from .projection import project_gdf
+from .settings import default_crs
 from .simplify import simplify_graph
 from .utils import log
 from .utils import make_str
@@ -41,6 +42,7 @@ from .utils import great_circle_vec
 from .utils import get_nearest_node
 from .utils import geocode
 from .utils import count_streets_per_node
+from .utils import overpass_json_from_file
 
 
 def save_to_cache(url, response_json):
@@ -108,7 +110,8 @@ def get_from_cache(url):
         # open the cache file for this url hash if it already exists, otherwise
         # return None
         if os.path.isfile(cache_path_filename):
-            response_json = json.load(io.open(cache_path_filename, encoding='utf-8'))
+            with io.open(cache_path_filename, encoding='utf-8') as cache_file:
+            	response_json = json.load(cache_file)
             log('Retrieved response from cache file "{}" for URL "{}"'.format(cache_path_filename, url))
             return response_json
 
@@ -287,7 +290,7 @@ def overpass_request(data, pause_duration=None, timeout=180, error_pause_duratio
 
     # define the Overpass API URL, then construct a GET-style URL as a string to
     # hash to look up/save to cache
-    url = 'http://www.overpass-api.de/api/interpreter'
+    url = 'http://overpass-api.de/api/interpreter'
     prepared_url = requests.Request('GET', url, params=data).prepare().url
     cached_response_json = get_from_cache(prepared_url)
 
@@ -428,11 +431,10 @@ def gdf_from_place(query, gdf_name=None, which_result=1, buffer_dist=None):
         if geometry['type'] not in ['Polygon', 'MultiPolygon']:
             log('OSM returned a {} as the geometry.'.format(geometry['type']), level=lg.WARNING)
 
-        # create the GeoDataFrame, name it, and set its original CRS to lat-long
-        # (EPSG 4326)
+        # create the GeoDataFrame, name it, and set its original CRS to default_crs
         gdf = gpd.GeoDataFrame.from_features(features)
         gdf.gdf_name = gdf_name
-        gdf.crs = {'init':'epsg:4326'}
+        gdf.crs = default_crs
 
         # if buffer_dist was passed in, project the geometry to UTM, buffer it
         # in meters, then project it back to lat-long
@@ -482,8 +484,8 @@ def gdf_from_places(queries, gdf_name='unnamed', buffer_dist=None):
     gdf = gdf.reset_index().drop(labels='index', axis=1)
     gdf.gdf_name = gdf_name
 
-    # set the original CRS of the GeoDataFrame to lat-long, and return it
-    gdf.crs = {'init':'epsg:4326'}
+    # set the original CRS of the GeoDataFrame to default_crs, and return it
+    gdf.crs = default_crs
     log('Finished creating GeoDataFrame with {} rows from {} queries'.format(len(gdf), len(queries)))
     return gdf
 
@@ -508,14 +510,14 @@ def get_osm_filter(network_type):
     # anything specifying motor=no. also filter out any non-service roads that
     # are tagged as providing parking, driveway, private, or emergency-access
     # services
-    filters['drive'] = ('["area"!~"yes"]["highway"!~"cycleway|footway|path|pedestrian|steps|track|'
+    filters['drive'] = ('["area"!~"yes"]["highway"!~"cycleway|footway|path|pedestrian|steps|track|corridor|'
                         'proposed|construction|bridleway|abandoned|platform|raceway|service"]'
                         '["motor_vehicle"!~"no"]["motorcar"!~"no"]["access"!~"private"]'
                         '["service"!~"parking|parking_aisle|driveway|private|emergency_access"]')
 
     # drive+service: allow ways tagged 'service' but filter out certain types of
     # service ways
-    filters['drive_service'] = ('["area"!~"yes"]["highway"!~"cycleway|footway|path|pedestrian|steps|track|'
+    filters['drive_service'] = ('["area"!~"yes"]["highway"!~"cycleway|footway|path|pedestrian|steps|track|corridor|'
                                 'proposed|construction|bridleway|abandoned|platform|raceway"]'
                                 '["motor_vehicle"!~"no"]["motorcar"!~"no"]["access"!~"private"]'
                                 '["service"!~"parking|parking_aisle|private|emergency_access"]')
@@ -529,7 +531,7 @@ def get_osm_filter(network_type):
 
     # biking: filter out foot ways, motor ways, private ways, and anything
     # specifying biking=no
-    filters['bike'] = ('["area"!~"yes"]["highway"!~"footway|motor|proposed|construction|abandoned|platform|raceway"]'
+    filters['bike'] = ('["area"!~"yes"]["highway"!~"footway|corridor|motor|proposed|construction|abandoned|platform|raceway"]'
                        '["bicycle"!~"no"]["service"!~"private"]["access"!~"private"]')
 
     # to download all ways, just filter out everything not currently in use or
@@ -1247,6 +1249,10 @@ def add_paths(G, paths, network_type):
             # add this path (in only one direction) to the graph
             add_path(G, data, one_way=True)
 
+        elif ('junction' in data and data['junction'] == 'roundabout') and not network_type == 'walk':
+            # roundabout are also oneway but not tagged as is
+            add_path(G, data, one_way=True)
+
         # else, this path is not tagged as one-way or it is a walking network
         # (you can walk both directions on a one-way street)
         else:
@@ -1289,8 +1295,8 @@ def create_graph(response_jsons, name='unnamed', retain_all=False, network_type=
     if len(elements) < 1:
         raise ValueError('There are no data elements in the response JSON objects')
 
-    # create the graph as a MultiDiGraph and set the original CRS to EPSG 4326
-    G = nx.MultiDiGraph(name=name, crs={'init':'epsg:4326'})
+    # create the graph as a MultiDiGraph and set the original CRS to default_crs
+    G = nx.MultiDiGraph(name=name, crs=default_crs)
 
     # extract nodes and paths from the downloaded osm data
     nodes = {}
@@ -1479,7 +1485,7 @@ def graph_from_point(center_point, distance=1000, distance_type='bbox',
         the (lat, lon) central point around which to construct the graph
     distance : int
         retain only those nodes within this many meters of the center of the
-        graph
+        graph, with distance determined according to distance_type argument
     distance_type : string
         {'network', 'bbox'} if 'bbox', retain only those nodes within a bounding
         box of the distance parameter. if 'network', retain only those nodes
@@ -1801,3 +1807,40 @@ def graph_from_place(query, network_type='all_private', simplify=True,
 
     log('graph_from_place() returning graph with {:,} nodes and {:,} edges'.format(len(list(G.nodes())), len(list(G.edges()))))
     return G
+
+
+def graph_from_file(filename, network_type='all_private', simplify=True,
+                    retain_all=False, name='unnamed'):
+    """
+    Create a networkx graph from OSM data in an XML file.
+
+    Parameters
+    ----------
+    filename : string
+        the name of a file containing OSM XML data
+    network_type : string
+        what type of street network to get
+    simplify : bool
+        if true, simplify the graph topology
+    retain_all : bool
+        if True, return the entire graph even if it is not connected
+    name : string
+        the name of the graph
+
+    Returns
+    -------
+    networkx multidigraph
+    """
+    # transmogrify file of OSM XML data into JSON
+    response_jsons = [overpass_json_from_file(filename)]
+    
+    # create graph using this response JSON
+    G = create_graph(response_jsons, network_type=network_type,
+                     retain_all=retain_all, name=name)
+
+    # simplify the graph topology as the last step.
+    if simplify:
+        G = simplify_graph(G)
+    
+    log('graph_from_file() returning graph with {:,} nodes and {:,} edges'.format(len(list(G.nodes())), len(list(G.edges()))))
+    return G
