@@ -85,7 +85,7 @@ def add_node_elevations(G, api_key, max_locations_per_batch=350,
     # add elevation as an attribute to the nodes
     df = pd.DataFrame(node_points, columns=['node_points'])
     df['elevation'] = [result['elevation'] for result in results]
-    nx.set_node_attributes(G, 'elevation', df['elevation'].to_dict())
+    nx.set_node_attributes(G, name='elevation', values=df['elevation'].to_dict())
     log('Added elevation data to all nodes.')
 
     return G
@@ -112,7 +112,7 @@ def add_edge_grades(G, add_absolute=True): # pragma: no cover
     # for each edge, calculate the difference in elevation from origin to
     # destination, then divide by edge length
     for u, v, data in G.edges(keys=False, data=True):
-        elevation_change = G.node[v]['elevation'] - G.node[u]['elevation']
+        elevation_change = G.nodes[v]['elevation'] - G.nodes[u]['elevation']
         grade = elevation_change / data['length']
         data['grade'] = grade
         if add_absolute:
